@@ -24,8 +24,9 @@ const config = {
   title: 'Rio Terminal',
   tagline: tagline[CURRENT_LOCALE],
   favicon: '/assets/rio-logo.ico',
-  url: 'https://raphamorim.io',
-  baseUrl: '/rio',
+  url: 'https://rioterm.com',
+  trailingSlash: false,
+  baseUrl: '/',
   organizationName: 'raphamorim',
   projectName: 'rio',
   onBrokenLinks: 'throw',
