@@ -161,22 +161,22 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                             return;
                         }
 
-                        if route_id == route.window.screen.ctx().current_route() {
-                            let timer_id = TimerId::new(Topic::RenderRoute, route_id);
-                            let event = EventPayload::new(
-                                RioEventType::Rio(RioEvent::Render),
-                                window_id,
-                            );
+                        // TODO: Optionally Allow check if is the current route
+                        // before schedule render. Using the following code below:
+                        // if route_id == route.window.screen.ctx().current_route() {
+                        let timer_id = TimerId::new(Topic::RenderRoute, route_id);
+                        let event = EventPayload::new(
+                            RioEventType::Rio(RioEvent::Render),
+                            window_id,
+                        );
 
-                            if !self.scheduler.scheduled(timer_id) {
-                                if let Some(limit) = route.window.wait_until() {
-                                    route.window.start_render_timestamp();
-                                    self.scheduler
-                                        .schedule(event, limit, false, timer_id);
-                                } else {
-                                    route.window.start_render_timestamp();
-                                    route.request_redraw();
-                                }
+                        if !self.scheduler.scheduled(timer_id) {
+                            if let Some(limit) = route.window.wait_until() {
+                                route.window.start_render_timestamp();
+                                self.scheduler.schedule(event, limit, false, timer_id);
+                            } else {
+                                route.window.start_render_timestamp();
+                                route.request_redraw();
                             }
                         }
                     }
@@ -1136,16 +1136,17 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                         route.window.screen.render();
                     }
                     RoutePath::ConfirmQuit => {
-                        route
-                            .window
-                            .screen
-                            .render_dialog("Do you want to leave Rio?");
+                        route.window.screen.render_dialog(
+                            "Quit Rio?",
+                            "Continue -> press escape key",
+                            "Quit -> press enter key",
+                        );
                     }
                 }
                 // println!("Time elapsed in render() is: {:?}", duration);
                 // }
 
-                if self.config.renderer.strategy.is_continuous()
+                if self.config.renderer.strategy.is_game()
                     && !self.config.renderer.disable_unfocused_render
                     && route.window.is_focused
                 {
