@@ -26,15 +26,23 @@ use std::ops::RangeInclusive;
 use rustc_hash::FxHashMap;
 use unicode_width::UnicodeWidthChar;
 
+#[derive(Default)]
+pub struct Search {
+    rich_text_id: Option<usize>,
+    active_search: Option<String>,
+}
+
 pub struct Renderer {
     is_vi_mode_enabled: bool,
     draw_bold_text_with_light_colors: bool,
     pub named_colors: Colors,
     pub colors: List,
     pub navigation: ScreenNavigation,
+    unfocused_split_opacity: f32,
     pub config_has_blinking_enabled: bool,
     pub config_blinking_interval: u64,
     ignore_selection_fg_color: bool,
+    pub search: Search,
     #[allow(unused)]
     pub option_as_alt: String,
     #[allow(unused)]
@@ -47,7 +55,6 @@ pub struct Renderer {
         (char, rio_backend::sugarloaf::font_introspector::Attributes),
         (usize, f32),
     >,
-    active_search: Option<String>,
 }
 
 impl Renderer {
@@ -79,6 +86,7 @@ impl Renderer {
         }
 
         Renderer {
+            unfocused_split_opacity: config.navigation.unfocused_split_opacity,
             draw_bold_text_with_light_colors: config.draw_bold_text_with_light_colors,
             macos_use_unified_titlebar: config.window.macos_use_unified_titlebar,
             config_blinking_interval: config.cursor.blinking_interval.clamp(350, 1200),
@@ -94,7 +102,7 @@ impl Renderer {
             ),
             named_colors,
             dynamic_background,
-            active_search: None,
+            search: Search::default(),
             font_cache: FxHashMap::default(),
             font_context: font_context.clone(),
         }
@@ -102,7 +110,7 @@ impl Renderer {
 
     #[inline]
     pub fn set_active_search(&mut self, active_search: Option<String>) {
-        self.active_search = active_search;
+        self.search.active_search = active_search;
     }
 
     #[inline]
@@ -302,6 +310,13 @@ impl Renderer {
                 }
             }
 
+            if !is_active {
+                style.color[3] = self.unfocused_split_opacity;
+                if let Some(mut background_color) = style.background_color {
+                    background_color[3] = self.unfocused_split_opacity;
+                }
+            }
+
             if square.flags.contains(Flags::GRAPHICS) {
                 // let graphics = square.graphics().map(|graphics| {
                 //     graphics
@@ -626,14 +641,89 @@ impl Renderer {
     }
 
     #[inline]
-    pub fn prepare_term(
+    fn update_search_rich_text(&mut self, content: &mut Content) {
+        if let Some(active_search_content) = &self.search.active_search {
+            if let Some(search_rich_text) = self.search.rich_text_id {
+                if active_search_content.is_empty() {
+                    content
+                        .sel(search_rich_text)
+                        .clear()
+                        .new_line()
+                        .add_text(
+                            &String::from("Search: type something..."),
+                            FragmentStyle {
+                                color: [
+                                    self.named_colors.foreground[0],
+                                    self.named_colors.foreground[1],
+                                    self.named_colors.foreground[2],
+                                    self.named_colors.foreground[3] - 0.3,
+                                ],
+                                ..FragmentStyle::default()
+                            },
+                        )
+                        .build();
+                } else {
+                    let mut style = FragmentStyle {
+                        color: self.named_colors.foreground,
+                        ..FragmentStyle::default()
+                    };
+                    let line = content.sel(search_rich_text);
+                    line.clear().new_line().add_text("Search: ", style);
+
+                    for character in active_search_content.chars() {
+                        if let Some((font_id, width)) =
+                            self.font_cache.get(&(character, style.font_attrs))
+                        {
+                            style.font_id = *font_id;
+                            style.width = *width;
+                        } else {
+                            let mut width = character.width().unwrap_or(1) as f32;
+                            let mut font_ctx = self.font_context.inner.lock();
+
+                            // Note we don't update cache from search bar
+                            if let Some((font_id, is_emoji)) =
+                                font_ctx.find_best_font_match(character, &style)
+                            {
+                                style.font_id = font_id;
+                                if is_emoji {
+                                    width = 2.0;
+                                }
+                            }
+                            style.width = width;
+                        };
+
+                        line.add_text_on_line(
+                            // Add on first line
+                            1,
+                            &character.to_string(),
+                            style,
+                        );
+                    }
+
+                    line.build();
+                }
+            }
+        }
+    }
+
+    #[inline]
+    pub fn update(
         &mut self,
         sugarloaf: &mut Sugarloaf,
         context_manager: &mut ContextManager<EventProxy>,
         hints: &mut Option<HintMatches>,
         focused_match: &Option<RangeInclusive<Pos>>,
     ) {
+        // In case rich text for search was not created
+        let has_search = self.search.active_search.is_some();
+        if has_search && self.search.rich_text_id.is_none() {
+            let search_rich_text = sugarloaf.create_temp_rich_text();
+            sugarloaf.set_rich_text_font_size(&search_rich_text, 12.0);
+            self.search.rich_text_id = Some(search_rich_text);
+        }
+
         let content = sugarloaf.content();
+
         let grid = context_manager.current_grid_mut();
         let active_index = grid.current;
 
@@ -702,26 +792,32 @@ impl Renderer {
             }
         }
 
+        self.update_search_rich_text(content);
+
         let window_size = sugarloaf.window_size();
         let scale_factor = sugarloaf.scale_factor();
         let mut objects = Vec::with_capacity(30);
         self.navigation.build_objects(
+            sugarloaf,
             (window_size.width, window_size.height, scale_factor),
             &self.named_colors,
             context_manager,
-            self.active_search.is_some(),
+            self.search.active_search.is_some(),
             &mut objects,
         );
 
-        if let Some(active_search_content) = &self.active_search {
-            search::draw_search_bar(
-                &mut objects,
-                &self.named_colors,
-                (window_size.width, window_size.height, scale_factor),
-                active_search_content,
-            );
+        if has_search {
+            if let Some(rich_text_id) = self.search.rich_text_id {
+                search::draw_search_bar(
+                    &mut objects,
+                    rich_text_id,
+                    &self.named_colors,
+                    (window_size.width, window_size.height, scale_factor),
+                );
+            }
 
-            self.active_search = None;
+            self.search.active_search = None;
+            self.search.rich_text_id = None;
         }
 
         for rte in context_manager.grid_objects() {
