@@ -450,11 +450,13 @@ impl Screen<'_> {
             self.clear_selection();
         }
         self.sugarloaf.resize(new_size.width, new_size.height);
-        self.context_manager
-            .current_grid_mut()
-            .resize(new_size.width as f32, new_size.height as f32);
+        let width = new_size.width as f32;
+        let height = new_size.height as f32;
+
+        for context_grid in self.context_manager.contexts_mut() {
+            context_grid.resize(width, height);
+        }
 
-        self.resize_all_contexts();
         self
     }
 
@@ -471,9 +473,12 @@ impl Screen<'_> {
         self.context_manager
             .current_grid_mut()
             .update_dimensions(&self.sugarloaf);
-        self.context_manager
-            .current_grid_mut()
-            .resize(new_size.width as f32, new_size.height as f32);
+        let width = new_size.width as f32;
+        let height = new_size.height as f32;
+
+        for context_grid in self.context_manager.contexts_mut() {
+            context_grid.resize(width, height);
+        }
 
         self
     }
@@ -999,11 +1004,13 @@ impl Screen<'_> {
                     }
                     Act::SelectNextSplitOrTab => {
                         self.cancel_search();
+                        self.clear_selection();
                         self.context_manager.switch_to_next_split_or_tab();
                         self.render();
                     }
                     Act::SelectPrevSplitOrTab => {
                         self.cancel_search();
+                        self.clear_selection();
                         self.context_manager.switch_to_prev_split_or_tab();
                         self.render();
                     }
@@ -2066,12 +2073,14 @@ impl Screen<'_> {
         self.sugarloaf.render();
     }
 
-    pub fn render_dialog(&mut self, content: &str) {
+    pub fn render_dialog(&mut self, content: &str, confirm: &str, close: &str) {
         self.sugarloaf.clear();
         crate::router::routes::dialog::screen(
             &mut self.sugarloaf,
             &self.context_manager.current().dimension,
             content,
+            confirm,
+            close,
         );
         self.sugarloaf.render();
     }
@@ -2100,7 +2109,7 @@ impl Screen<'_> {
             None
         };
 
-        self.renderer.prepare_term(
+        self.renderer.update(
             &mut self.sugarloaf,
             &mut self.context_manager,
             &mut search_hints,
