@@ -191,7 +191,7 @@ pub struct Run<'a> {
     pub(super) run: &'a RunData,
 }
 
-impl<'a> Run<'a> {
+impl Run<'_> {
     /// Returns the span that contains the run.
     #[inline]
     pub fn span(&self) -> FragmentStyle {
