@@ -5,10 +5,12 @@ pub mod font_introspector;
 pub mod layout;
 mod sugarloaf;
 
+// Expose WGPU
+pub use wgpu;
+
 pub use font_introspector::{Stretch, Style, Weight};
 
 pub use crate::sugarloaf::{
-    compositors::SugarCompositors,
     graphics::{
         ColorType, Graphic, GraphicData, GraphicId, Graphics, ResizeCommand,
         ResizeParameter, MAX_GRAPHIC_DIMENSIONS,
@@ -17,6 +19,7 @@ pub use crate::sugarloaf::{
     Sugarloaf, SugarloafErrors, SugarloafRenderer, SugarloafWindow, SugarloafWindowSize,
     SugarloafWithErrors,
 };
+pub use components::filters::Filter;
 pub use components::quad::{ComposedQuad, Quad};
 pub use components::rect::Rect;
 pub use layout::{
